==> haskell-ordered-containers-0.2.4-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ordered-containers
version:              0.2.4
visibility:           public
id:                   ordered-containers-0.2.4-LnO56NkpGyGGIP4Bkk0JD2
key:                  ordered-containers-0.2.4-LnO56NkpGyGGIP4Bkk0JD2
license:              BSD-3-Clause
maintainer:           me@dmwit.com
author:               Daniel Wagner
synopsis:
    Set- and Map-like types that remember the order elements were inserted

category:             Data
abi:                  e8b5493e12a7a920146101e3df11c18f
exposed:              True
exposed-modules:
    Data.Map.Ordered Data.Map.Ordered.Strict Data.Set.Ordered

hidden-modules:       Data.Map.Ordered.Internal Data.Map.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ordered-containers
hs-libraries:         HSordered-containers-0.2.4-LnO56NkpGyGGIP4Bkk0JD2
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.4.0-3qP5TxmiOmVGP173jSDFZO

haddock-interfaces:
    /usr/share/doc/haskell-ordered-containers/html/ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ordered-containers-0.2.4-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ordered-containers
version:              0.2.4
visibility:           public
id:                   ordered-containers-0.2.4-9Z1IPGPP0nR64UcxttwlAD
key:                  ordered-containers-0.2.4-9Z1IPGPP0nR64UcxttwlAD
license:              BSD-3-Clause
maintainer:           me@dmwit.com
author:               Daniel Wagner
synopsis:
    Set- and Map-like types that remember the order elements were inserted

category:             Data
abi:                  79fb441d1fdfd8edb8d27328ea4ee8d1
exposed:              True
exposed-modules:
    Data.Map.Ordered Data.Map.Ordered.Strict Data.Set.Ordered

hidden-modules:       Data.Map.Ordered.Internal Data.Map.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ordered-containers
hs-libraries:         HSordered-containers-0.2.4-9Z1IPGPP0nR64UcxttwlAD
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.4.0-AtkYwZfsO44KEb9h1CQ6ig

haddock-interfaces:
    /usr/share/doc/haskell-ordered-containers/html/ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
